@@ -28,17 +28,16 @@ from elasticsearch.exceptions import ConflictError, RequestError
 import json
 import importlib
 
-sys.path.append(".")
-
-from .app.geocodingBackend import GeneralGeocodingManager, GeneralReverseManager, DensityRadius, \
+from places_geocode.app.geocodingBackend import GeneralGeocodingManager, GeneralReverseManager, DensityRadius, \
     Convex, RunModel
 
 # models import
-from .app.models import frontend_models, density_models, common_models, user_metrics_models as USM
-from .app.logger import log_error
+from places_geocode.app.models import frontend_models, density_models, common_models, user_metrics_models as USM
+from places_geocode.app.logger import log_error
 
 # import cython files
-from .app.CythonOperations import create_convex_array, check_dups, zip_coordinate, check_lat_long_length, \
+from ctypes import *
+from places_geocode.app.CythonOperations import create_convex_array, check_dups, zip_coordinate, check_lat_long_length, \
     check_address_length, zip_coordinates_elastic, create_convex_elastic, coordinate_conv_package
 
 
@@ -126,7 +125,7 @@ class PeekGeoUtilities(metaclass=SingletonType):
         return dict(date=date_now, time=time_now, official_timestamp=official_timestamp)
 
     @staticmethod
-    def handle_coordinates(coordinates: List[Union[float, int]], reverse_param: bool):
+    def handle_coordinates(coordinates: list, reverse_param: bool):
         """handle reversals and such"""
         if reverse_param:
             return coordinates[::-1]
@@ -148,7 +147,7 @@ class PeekGeoUtilities(metaclass=SingletonType):
             return stringified_coord_data
 
     @staticmethod
-    def handle_batch_reverse_coords(latitudes: List[Union[float, int]], longitudes: List[Union[float, int]],
+    def handle_batch_reverse_coords(latitudes: list, longitudes: list,
                                     reverse_param: bool,
                                     coordinate_file: UploadFile = File(None)) -> Any:
 
@@ -313,7 +312,7 @@ class PeekGeoUtilities(metaclass=SingletonType):
                 headers={'Error_Description': "Reset token or validate current token"}
             )
 
-    def verify_token(self, token: str) -> Union[bool, None]:
+    def verify_token(self, token: str) -> Any:
         """verify the access token to API endpoint"""
 
         try:
@@ -462,7 +461,7 @@ class GlobalDataModel(BaseModel):
     batch_endpoint_max: Optional[int] = 125
     max_load_radius: Optional[int] = 2000
     token_length: Optional[int] = 12
-    call_pay_plans: Optional[Dict[Union[int, str], Tuple[int, int]]] = {0: (100, 0),
+    call_pay_plans: Optional[Dict[Any, Tuple[int, int]]] = {0: (100, 0),
                                                                         20: (13000, 20),
                                                                         60: (100000, 50),
                                                                         125: (350000, 200)}
@@ -550,7 +549,7 @@ def check_radius(radius: int) -> bool:
         return False
 
 
-def radius_response_fail(radius: int, location: List[Union[float, int]]) -> Union[None, dict]:
+def radius_response_fail(radius: int, location: list) -> Any:
     """define the failed radius response once exceeded"""
     return {'meta': {'build': 'Radius_EXC', 'status': 505, 'matching': 0,
                      'timestamps': {'date': str(date.today()),
@@ -564,7 +563,7 @@ def radius_response_fail(radius: int, location: List[Union[float, int]]) -> Unio
 
 
 def success_response(date_results: dict,
-                     location: List[Union[float, int]],
+                     location: list,
                      radius: int,
                      result_arr: Any):
     """success response creation"""
@@ -585,8 +584,8 @@ def success_response(date_results: dict,
 class SetUpLoadRadius:
     """set up the load radius with get_params function"""
 
-    def __init__(self, token: str, coordinates: List[Union[float, int]],
-                 radius: Union[int, float], reverse_param: bool = False):
+    def __init__(self, token: str, coordinates: list,
+                 radius: Any, reverse_param: bool = False):
         self.token = token
         self.coordinates = coordinates
         self.radius = radius
@@ -728,7 +727,7 @@ def duplicate_edge_check(edges_duplicate: list):
         return False
 
 
-def area_exceeded_response(area: Union[float, int, None], date_results: dict) -> Dict:
+def area_exceeded_response(area: Any, date_results: dict) -> Dict:
     """area exceeded response"""
 
     return {
@@ -743,7 +742,7 @@ def area_exceeded_response(area: Union[float, int, None], date_results: dict) ->
 
 
 # noinspection PyUnresolvedReferences
-def area_check(class_obj: Callable, latitudes: List[Union[float, int]], longitudes: List[Union[float, int]]) -> bool:
+def area_check(class_obj: Callable, latitudes: list, longitudes: list) -> bool:
     """check for area exceeding"""
     area = class_obj.get_polygon_area(latitudes, longitudes)
     if area > GlobalDataModel().convex_area_limit:
@@ -770,7 +769,7 @@ def convex_success_response(edges: list, results: Any, date_results: dict):
 class SetUpConvex:
     """set up convex class for polygon searches"""
 
-    def __init__(self, token: str, coordinates: List[Union[float, int]], reverse_param: Optional[bool] = False):
+    def __init__(self, token: str, coordinates: list, reverse_param: Optional[bool] = False):
         self.token = token
         self.coordinates = coordinates
         self.reverse_param = reverse_param
@@ -878,7 +877,7 @@ def exceeded_radius_check(radius: int, unit: str) -> bool:
         return True
 
 
-def exceeded_radius_response(radius: int, unit_out: str, unit_in: str, coordinates: List[Union[float, int]],
+def exceeded_radius_response(radius: int, unit_out: str, unit_in: str, coordinates: list,
                              date_results: dict) -> Dict:
     """exceeded radius for density coordinate query"""
 
@@ -895,7 +894,7 @@ def exceeded_radius_response(radius: int, unit_out: str, unit_in: str, coordinat
     }
 
 
-def success_density_response(result: Union[float, int, None], date_results: dict, unit_out: str, supplied: dict):
+def success_density_response(result: Any, date_results: dict, unit_out: str, supplied: dict):
     """create the success response for the density endpoint"""
     return {'meta': {'build': 'OK', 'status': 200, 'matching': 1,
                          'timestamps': {'date': date_results['date'],
@@ -912,13 +911,13 @@ class SetUpDensity:
     """density base set up class creation"""
 
     def __init__(self, token: str,
-                 coordinate: Optional[Union[list, None]] = None,
+                 coordinate: Optional[Any] = None,
                  unit_in: Optional[str] = "ft",
                  unit_out: Optional[str] = "ft",
-                 radius: Optional[Union[float, int, None]] = None,
-                 reverse_param: Optional[Union[bool, None]] = False,
-                 custom_option: Optional[Union[frontend_models.DensitySearch('do'), None]] = None,
-                 custom_utility: Union[Optional[Union[str, int, float, None]], None] = None
+                 radius: Optional[Any] = None,
+                 reverse_param: Optional[Any] = False,
+                 custom_option: Any = None,
+                 custom_utility: Any = None
                  ):
         self.token = token
         self.coordinate = coordinate
@@ -1049,8 +1048,8 @@ async def density_search_api(class_dependency: dict) -> dict:
 ########################### REVERSE GEOCODER ###################################
 
 
-def success_single_reverse(date_results: dict, formatted_address: str, location: List[Union[float, int]],
-                           radius: Union[float, int], address_components: dict, confidence: float):
+def success_single_reverse(date_results: dict, formatted_address: str, location: list,
+                           radius: Any, address_components: dict, confidence: float):
     """create success case singular reverse geocoding response"""
 
     return {'meta': {'build': 'OK', 'status': 200, 'matching': 1,
@@ -1066,8 +1065,8 @@ def success_single_reverse(date_results: dict, formatted_address: str, location:
             }
 
 
-def poi_not_found_response(date_results: dict, formatted_address: Union[str, None], radius: int,
-                           address_components: dict, location: List[Union[float, int]]) -> Dict:
+def poi_not_found_response(date_results: dict, formatted_address: Any, radius: int,
+                           address_components: dict, location: list) -> Dict:
     """not found response for place of interest"""
 
     return {'meta': {'build': 'POI_NULL', 'status': 200, 'matching': 0,
@@ -1087,8 +1086,8 @@ class SetUpReverse:
     """radius setup class for basic functionalities"""
 
     def __init__(self, token: str,
-                 coordinate: List[Union[float, int]],
-                 radius: Optional[Union[float, int]] = 10,
+                 coordinate: list,
+                 radius: Any = 10,
                  reverse_param: Optional[bool] = False
                  ):
         self.token = token
@@ -1217,7 +1216,7 @@ class SetUpBatchReverse:
     def __init__(self, token: str,
                  latitudes: Optional[List[float]] = Query(None),
                  longitudes: Optional[List[float]] = Query(None),
-                 radius: Optional[Union[int, float]] = 10,
+                 radius: Any = 10,
                  coordinate_file: Optional[UploadFile] = File(None),
                  reverse_param: Optional[bool] = False
                  ):
@@ -1600,13 +1599,13 @@ class places:
 
         # reverse_parameter extraction
         try:
-            reverse_param: Union[bool, None] = additional_args['reverse_param']
+            reverse_param: Any = additional_args['reverse_param']
         except KeyError:
-            reverse_param: Union[bool, None] = None
+            reverse_param: Any = None
 
         return reverse_param
 
-    def load_properties(self, coordinates: list = (), radius: Union[float, int] = 10, **additionals):
+    def load_properties(self, coordinates: list = (), radius: Any = 10, **additionals):
         """load properties facade for package purposes"""
 
         # get token and reverse parameter
@@ -1625,8 +1624,8 @@ class places:
         # create response and send it
         return convex_search_api({"token": self.token, "coordinates": coordinates, "reverse_param": reverse_param})
 
-    def density(self, unit_in="ft", unit_out="ft", coordinate: list = None, radius: Union[float, int] = 1,
-                custom_option: str = None, custom_utility: Union[float, int, str] = None, **additionals) -> Any:
+    def density(self, unit_in="ft", unit_out="ft", coordinate: list = None, radius: Any = 1,
+                custom_option: str = None, custom_utility: Any = None, **additionals) -> Any:
         """density facade function for places package"""
 
         # get token and reverse parameter
@@ -1637,7 +1636,7 @@ class places:
              "radius": radius, "reverse_param": reverse_param, "custom_option": custom_option,
              "custom_utility": custom_utility}))
 
-    def reverse(self, coordinate: list = (), radius: Union[float, int] = 10, **additionals) -> Any:
+    def reverse(self, coordinate: list = (), radius: Any = 10, **additionals) -> Any:
         """reverse geocoding facade method for Places package"""
         # get token and reverse parameter
         reverse_param = self.process_basic_args(additionals)
@@ -1646,7 +1645,7 @@ class places:
         return run(reverse_geocode_api({"token": self.token, "coordinate": coordinate, "radius": radius,
                                         "reverse_param": reverse_param}))
 
-    def batch_reverse(self, coordinates: List[list] = (()), radius: Union[float, int] = 10, coordinate_file: UploadFile = None,
+    def batch_reverse(self, coordinates: List[list] = (()), radius: Any = 10, coordinate_file: UploadFile = None,
                       **additionals) -> Any:
         """batch reverse geocoding facade method for Places package"""
 
@@ -1660,7 +1659,7 @@ class places:
         return run(batch_reverse_api({"token": self.token, "latitudes": lats, "longitudes": longs, "radius": radius,
                                   "coordinate_file": coordinate_file, "reverse_param": reverse_param}))
 
-    def forward(self, full_address: str = None, street: str = None, number: Union[str, int] = None, postcode: int = None, region: str = None, city:
+    def forward(self, full_address: str = None, street: str = None, number: Any = None, postcode: int = None, region: str = None, city:
                       str = None, unit=None) -> Any:
         """facade method for forward geocoding on Places API"""
 
